function [xdot_lon] = eom_longitudinal(x,delta,v,phi,theta,p,r,P)

% States = [u w q]
% Inputs = [delta_e delta_t]
stall = false;

u = x(1);
w = x(2);
q = x(3);
delta_e = delta(1);
delta_t = delta(2);

Va = sqrt(u^2 + v^2 + w^2);
alpha = atan2(w,u);              
beta = asin(v/Va);

D = dragforce(Va,alpha,beta,q,delta_e,P,stall);
Y = 0;
L = liftforce(Va,alpha,q,delta_e,P,stall);
l = 0;
m = pitchmoment(Va,alpha,q,delta_e,P);
n = 0;

f_x = [cos(alpha), -sin(alpha)]*[-D, -L]';
f_y = Y;
f_z = [sin(alpha), cos(alpha)]*[-D, -L]';

fa = [f_x,f_y,f_z]';
ma = [l,m,n]';

fp = thrustforce(Va,delta_t,P);
mp = thrustmoment(delta_t,P);

fg = gravityforce(phi,theta,P);

F = fa + fp + fg;
M = ma + mp;

X = F(1);
Y = F(2);
Z = F(3);
l = M(1);
m = M(2);
n = M(3);

vel_dot = [r*v - q*w;
           p*w - r*u;
           q*u - p*v] + 1/P.m * [X, Y, Z]';

angrate_dot = [P.L1*p*q - P.L2*q*r;
               P.L5*p*r - P.L6*(p^2-r^2);
               P.L7*p*q-P.L1*q*r] + ... 
               [P.L3*l + P.L4*n;
               (1/P.Jy)*m;
               P.L4*l + P.L8*n];

udot = vel_dot(1);
wdot = vel_dot(3);
qdot = angrate_dot(2);

% CLALPHA = P.C_L_0 + P.C_L_alpha * alpha;
% CDALPHA = P.C_D_0 + P.C_D_alpha1 * alpha;
% 
% C_X_0 = 0; % Has not yet been identified
% C_Z_0 = 0; % Has not yet been identified
% C_X_alpha = -CDALPHA*cos(alpha) + CLALPHA*sin(alpha);
% C_X_q = -P.C_D_q*cos(alpha) + P.C_L_q*sin(alpha);
% C_X_delta_e = -P.C_D_delta_e*cos(alpha) + P.C_L_delta_e*sin(alpha);
% C_Z_alpha = -CDALPHA*sin(alpha) - CLALPHA*cos(alpha);
% C_Z_q = -P.C_D_q*sin(alpha) - P.C_L_q*cos(alpha);
% C_Z_delta_e = -P.C_D_delta_e*sin(alpha) - P.C_L_delta_e*cos(alpha);
% 
% udot = -q*w-P.g*sin(theta)+(P.rho*(u^2 + w^2)*P.S_wing)/(2*P.m)* ...
%     (C_X_0+C_X_alpha*atan(w/u)+C_X_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2 + w^2)*P.S_wing*C_X_q*P.c*q)/(4*P.m) + ...
%     (P.rho*P.S_prop*P.C_prop)/(2*P.m)*((P.k_motor*delta_t)^2-(u^2+w^2));
% wdot = q*u+P.g*cos(theta)+(P.rho*(u^2+w^2)*P.S_wing)/(2*P.m)* ...
%     (C_Z_0+C_Z_alpha*atan(w/u)+C_Z_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2+w^2)*P.S_wing*C_Z_q*P.c*q)/(4*P.m);
% qdot = (P.rho*(u^2+w^2)*P.c*P.S_wing)/(2*P.Jy)*(P.C_m_0 + ...
%     P.C_m_alpha*atan(w/u)+P.C_m_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2+w^2)*P.S_wing*P.C_m_q*(P.c)^2*q)/4*P.Jy;

xdot_lon = [udot;wdot;qdot];
end