function xdot_lon  = eom_longitudinal_sysid(x,delta,v,phi,theta,p,r,P,sysparam)

% States = [u w q]
% Inputs = [delta_e delta_t]

C_L_0 = sysparam(1);
C_L_alpha = sysparam(2);
C_L_delta_e = sysparam(3);
C_L_q = sysparam(4);
C_D_0 = sysparam(5);
C_D_alpha1 = sysparam(6);
C_D_delta_e = sysparam(7);
C_D_q = sysparam(8);
C_m_alpha = sysparam(9);
C_m_delta_e = sysparam(10);
C_m_q = sysparam(11);
C_m_0 = sysparam(12);

u = x(1);
w = x(2);
q = x(3);
delta_e = delta(1);
delta_t = delta(2);

Va = sqrt(u^2 + v^2 + w^2);
alpha = atan2(w,u);              
beta = asin(v/Va);

C_D_alpha = C_D_0 + C_D_alpha1*alpha + P.C_D_alpha2*alpha^2;
C_D = C_D_alpha + P.c*C_D_q*q/(2*Va) + C_D_delta_e*delta_e^2;
D = (0.5*P.rho*Va^2)*P.S_wing*C_D;
Y = 0;
C_L_alpha = C_L_0 + C_L_alpha * alpha;
C_L = C_L_alpha + P.c*C_L_q*q/(2*Va) + C_L_delta_e*delta_e;
L = 0.5*P.rho*Va^2*P.S_wing*C_L;
l = 0;
C_m = C_m_0 + C_m_alpha*alpha + (C_m_q*P.c*q)/(2*Va) + ...
    C_m_delta_e*delta_e;
m = 0.5*P.rho*Va^2*P.S_wing*P.c*C_m;
n = 0;

f_x = [cos(alpha), -sin(alpha)]*[-D, -L]';
f_y = Y;
f_z = [sin(alpha), cos(alpha)]*[-D, -L]';

fa = [f_x,f_y,f_z]';
ma = [l,m,n]';

fp = thrustforce(Va,delta_t,P);
mp = thrustmoment(delta_t,P);

fg = gravityforce(phi,theta,P);

F = fa + fp + fg;
M = ma + mp;

X = F(1);
Y = F(2);
Z = F(3);
l = M(1);
m = M(2);
n = M(3);

vel_dot = [r*v - q*w;
           p*w - r*u;
           q*u - p*v] + 1/P.m * [X, Y, Z]';

angrate_dot = [P.L1*p*q - P.L2*q*r;
               P.L5*p*r - P.L6*(p^2-r^2);
               P.L7*p*q-P.L1*q*r] + ... 
               [P.L3*l + P.L4*n;
               (1/P.Jy)*m;
               P.L4*l + P.L8*n];

udot = vel_dot(1);
wdot = vel_dot(3);
qdot = angrate_dot(2);

% alpha = atan(w/u);
% CLALPHA = C_L_0 + C_L_alpha * alpha;
% CDALPHA = C_D_0 + C_D_alpha1 * alpha;
% 
% C_X_0 = 0; % Has not yet been identified
% C_Z_0 = 0; % Has not yet been identified
% C_X_alpha = -CDALPHA*cos(alpha) + CLALPHA*sin(alpha);
% C_X_q = -C_D_q*cos(alpha) + C_L_q*sin(alpha);
% C_X_delta_e = -C_D_delta_e*cos(alpha) + C_L_delta_e*sin(alpha);
% C_Z_alpha = -CDALPHA*sin(alpha) - CLALPHA*cos(alpha);
% C_Z_q = -C_D_q*sin(alpha) - C_L_q*cos(alpha);
% C_Z_delta_e = -C_D_delta_e*sin(alpha) - C_L_delta_e*cos(alpha);
% 
% udot = -q*w-P.g*sin(theta)+(P.rho*(u^2 + w^2)*P.S_wing)/(2*P.m)* ...
%     (C_X_0+C_X_alpha*atan(w/u)+C_X_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2 + w^2)*P.S_wing*C_X_q*P.c*q)/(4*P.m) + ...
%     (P.rho*P.S_prop*P.C_prop)/(2*P.m)*((P.k_motor*delta_t)^2-(u^2+w^2));
% wdot = q*u+P.g*cos(theta)+(P.rho*(u^2+w^2)*P.S_wing)/(2*P.m)* ...
%     (C_Z_0+C_Z_alpha*atan(w/u)+C_Z_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2+w^2)*P.S_wing*C_Z_q*P.c*q)/(4*P.m);
% qdot = (P.rho*(u^2+w^2)*P.c*P.S_wing)/(2*P.Jy)*(P.C_m_0 + ...
%     C_m_alpha*atan(w/u)+C_m_delta_e*delta_e) + ...
%     (P.rho*sqrt(u^2+w^2)*P.S_wing*C_m_q*(P.c)^2*q)/4*P.Jy;


xdot_lon = [udot;wdot;qdot];
end