function [A,B,C,D,x_star] = linearization(x0,Va,R,gamma,P,statespace)
% Linearized dynamics are determined by finding df/dx and df/du
% evaluated at the trim states x* and u*, where f is f(x,u)
syms x [12 1]
syms u [3 1] 
syms xlat [5 1]
syms ulat [1 1]
syms xlon [5 1]
syms ulon [2 1]

% Compute trim
[x_star,~] = trim(Va, R, gamma, x0, P);
% Have to change from vector to struct in order to substitute in A,B
x_trim = struct('x1',x_star(1),'x2',x_star(2),'x3',x_star(3),...
    'x4',x_star(4),'x5',x_star(5),'x6',x_star(6),'x7',x_star(7),...
    'x8',x_star(8),'x9',x_star(9),'x10',x_star(10),'x11',x_star(11),...
    'x12',x_star(12),'u1',x_star(13),'u2',x_star(14),'u3',x_star(15));

f = equationsOfMotion(x,u,P,statespace);
if isequal(statespace,'full')
    dfdx = jacobian(f,x);
    dfdu = jacobian(f,u);
    D = zeros(3,12);
elseif isequal(statespace,'lateral')
    xlat(1) = x5;
    xlat(2) = x10;
    xlat(3) = x12;
    xlat(4) = x7;
    xlat(5) = x9;
    ulat(1) = u2;
    dfdx = jacobian(f,xlat);
    dfdu = jacobian(f,ulat);
    D = [0 0 0 0 0]';
elseif isequal(statespace,'longitudinal')
    xlon(1) = x4;
    xlon(2) = x6;
    xlon(3) = x11;
    xlon(4) = x8;
    xlon(5) = x3;
    ulon(1) = u1;
    ulon(2) = u3;
    dfdx = jacobian(f,xlon);
    dfdu = jacobian(f,ulon);
    D = [0 0 0 0 0;
         0 0 0 0 0]';
else 
    disp('Not a state-space')
end
    
A_mat = real(dfdx);
B_mat = real(dfdu);

A = double(subs(A_mat, fieldnames(x_trim), struct2cell(x_trim)));
B = double(subs(B_mat, fieldnames(x_trim), struct2cell(x_trim)));
C = [1 0 0 0 0;
    0 1 0 0 0;
    0 0 1 0 0;
    0 0 0 1 0;
    0 0 0 0 1];

end


