close all;
clear;
clc;

addpath('GNC')
addpath('forces')
addpath('C:\Users\tobiasva\Documents\Casadi')
% addpath('/Users/tobiasvaage/casadi-osx-matlabR2015a-v3.5.5')
import casadi.*
params;
load('sol_x.mat','sol_x') 
%% Initializations and constants

h  = 0.02;   % sampling time [s]
N = 200;     % no. of samples
fs = 1/h;    % sampling frequency [Hz]
input_freq = 5;    % Input frequenzy [Hz]
T = 1/input_freq;   % Period

pn = MX.sym('pn');
pe = MX.sym('pe');
pd = MX.sym('pd');
u = MX.sym('u');
v = MX.sym('v');
w = MX.sym('w');
phi = MX.sym('phi');
theta = MX.sym('theta');
psi = MX.sym('psi');
p = MX.sym('p');
q = MX.sym('q');
r = MX.sym('r');

delta_e = MX.sym('delta_e');
delta_a = MX.sym('delta_a');
delta_t = MX.sym('delta_t');

xlat = [v;p;r];
ulat = delta_a;
xlon = [u;w;q];
ulon = [delta_e;delta_t];

% states = [pn;pe;pd;u;v;w;phi;theta;psi;p;q;r];
states = xlat;
% states = xlon;
% controls = [delta_e;delta_a;delta_t];
controls = ulat;
% controls = ulon;

% Initial conditions for trim
%     pn pe pd   u  v  w  phi theta psi p  q  r  e  a  t
x0 = [0  0  -100 18 0  0  0   0     0   0  0  0  0  0  0.1];

% Trim calculation
Va_d = 18;
R_d = Inf;
gamma_d = 0;
[x,~] = trim(Va_d, R_d, gamma_d, x0, P);

delta_e_trim = x(13);
delta_a_trim = x(14);

x0_RK4 = x(1:12);
x0_lon = [x(4), x(6), x(11)]';
x0_lat = [x(5), x(10), x(12)]';
save('x0_lon.mat','x0_lon');
save('x0_lat.mat','x0_lat')

x_lon = zeros(N+1,3);
x_lat = zeros(N+1,3);

x_lon(1,:) = x0_lon;
x_lat(1,:) = x0_lat;

time = zeros(N+1,1);
u_lon = zeros(N+1,2);
u_lat = zeros(N+1,1);

%% Generate input sequence for SYSID
for i = 1:N+1
   
   t = (i-1)*h;      % time [s]

   if t > 2
       x(13) = delta_e_trim + deg2rad(10);
       x(14) = delta_a_trim + deg2rad(10);
   end
   if t > 2 + T/2
       x(13) = delta_e_trim - deg2rad(10);
       x(14) = delta_a_trim - deg2rad(10);
   end
   if t > 2 + T
   x(13) = delta_e_trim;
   x(14) = delta_a_trim;
   end

   time(i) = t;

   u_lon(i,:) = [x(13) x(15)];
   u_lat(i,:) = x(14);
   
 
end 
t = time;
save('t.mat','t')
save('u_lon.mat','u_lon')
save('u_lat.mat','u_lat')

%% Runge Kutta 4

% xdot = eom_longitudinal(states,controls,x(5),x(7),x(8),x(10),x(12),P);
% xdot = eom_longitudinal_sysid(states,controls,x(5),x(7),x(8),x(10),x(12),P,sol_x);
% xdot = eom_lateral(states,controls,x(4),x(6),x(7),x(8),x(11),P);
xdot = eom_lateral_sysid(states,controls,x(4),x(6),x(7),x(8),x(11),P,sol_x);

rhs = xdot;

% Form an ode function
ode = Function('ode',{states,controls},{rhs});
% Build an integrator for this system: Runge Kutta 4 integrator
k1 = ode(states,controls);
k2 = ode(states+h/2.0*k1,controls);
k3 = ode(states+h/2.0*k2,controls);
k4 = ode(states+h*k3,controls);

states_final = states+h/6.0*(k1+2*k2+2*k3+k4);

one_step = Function('one_step',{states, controls},{states_final});
X = states;
X = one_step(X, controls);
one_sample = Function('one_sample',{states, controls}, {X});
one_sample = one_sample.expand();
all_samples = one_sample.mapaccum('all_samples', N);

% X_sim = full(all_samples(x0_lon,u_lon(1:200,:)'));
X_sim = full(all_samples(x0_lat,u_lat(1:200,:)'));

% x_lon(2:N+1,:) = X_sim';
x_lat(2:N+1,:) = X_sim';

% x_lon = x_lon + normrnd(0,0.1,N+1,3);
% x_lat = x_lat + normrnd(0,0.1,N+1,3);

save('x_lon.mat','x_lon')
save('x_lat.mat','x_lat')

% Longitudinal states
u = x_lon(:,1);
w = x_lon(:,2);
q = rad2deg(x_lon(:,3));

% Lateral states
v = x_lat(:,1);
p = rad2deg(x_lat(:,2));
r = rad2deg(x_lat(:,3));

delta_e = rad2deg(u_lon(:,1)); % deg
delta_a = rad2deg(u_lat);      % deg
delta_t = u_lon(:,2);          % -

% Longitudinal
figure(1)
figure(gcf)
subplot(311)
plot(t,u,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$u$ $[m/s]$','Interpreter','latex');

subplot(312)
plot(t,w,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$w$ $[m/s]$','Interpreter','latex');

subplot(313)
plot(t,q,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$q$ $[deg/s]$','Interpreter','latex');
sgtitle('Longitudinal Dynamics')

% Lateral
figure(2)
figure(gcf)
subplot(311)
plot(t,v,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$v$ $[m/s]$','Interpreter','latex');

subplot(312)
plot(t,p,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$p$ $[deg/s]$','Interpreter','latex');

subplot(313)
plot(t,r,'b','Linewidth',1);
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$r$ $[deg/s]$','Interpreter','latex');
sgtitle('Lateral Dynamics')

figure(3)
figure(gcf)
subplot(211)
plot(t,delta_e,'b','Linewidth',1)
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$\delta_e$ [$deg$]','Interpreter','latex','FontSize',12);

subplot(212)
plot(t,delta_a,'r','Linewidth',1)
xlabel('$time$ $[s]$','Interpreter','latex');
ylabel('$\delta_a$ [$deg$]','Interpreter','latex','FontSize',12);
sgtitle('Input Signals')
% 
% subplot(313)
% plot(t,delta_t,'b','Linewidth',1)
% xlabel('$time$ $[s]$','Interpreter','latex');
% ylabel('$\delta_t$','Interpreter','latex');
% sgtitle('Input Sequence')
